@@ -288,27 +288,21 @@ put it in magit-key-mode-key-maps for fast lookup."
     (define-key map (kbd "?") `(lambda ()
                                  (interactive)
                                  (magit-key-mode-help ',for-group)))
-
-    (flet ((defkey (k action)
-             (when (and (lookup-key map (car k))
-                        (not (numberp (lookup-key map (car k)))))
-               (message "Warning: overriding binding for `%s' in %S"
-                        (car k) for-group)
-               (ding)
-               (sit-for 2))
-             (define-key map (car k)
-               `(lambda () (interactive) ,action))))
-      (when actions
-        (dolist (k actions)
-          (defkey k `(magit-key-mode-command ',(nth 2 k)))))
-      (when switches
-        (dolist (k switches)
-          (defkey k `(magit-key-mode-add-option ',for-group ,(nth 2 k)))))
-      (when arguments
-        (dolist (k arguments)
-          (defkey k `(magit-key-mode-add-argument
-                      ',for-group ,(nth 2 k) ',(nth 3 k))))))
-
+    (dolist (k actions)
+      (define-key map (car k)
+        `(lambda ()
+           (interactive)
+           (magit-key-mode-command ',(nth 2 k)))))
+    (dolist (k switches)
+      (define-key map (car k)
+        `(lambda ()
+           (interactive)
+           (magit-key-mode-add-option ',for-group ,(nth 2 k)))))
+    (dolist (k arguments)
+      (define-key map (car k)
+        `(lambda ()
+           (interactive)
+           (magit-key-mode-add-argument ',for-group ,(nth 2 k) ',(nth 3 k)))))
     (push (cons for-group map) magit-key-mode-key-maps)
     map))
 
